Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/gitlab-org/gitlab-foss.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGitLab Bot <gitlab-bot@gitlab.com>2021-07-29 18:09:48 +0300
committerGitLab Bot <gitlab-bot@gitlab.com>2021-07-29 18:09:48 +0300
commitf4d51a9f71cf3d4b0874a3e1948fe3c1ea193c4d (patch)
tree7ae3da76e824c435167dd108721c0124ad2ee484 /rubocop
parent2dedd78ef505a0ab0a379c7340a3fcba56ada663 (diff)
Add latest changes from gitlab-org/gitlab@master
Diffstat (limited to 'rubocop')
-rw-r--r--rubocop/cop/gitlab/bulk_insert.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/rubocop/cop/gitlab/bulk_insert.rb b/rubocop/cop/gitlab/bulk_insert.rb
index 83d879ddf44..4c8c232043f 100644
--- a/rubocop/cop/gitlab/bulk_insert.rb
+++ b/rubocop/cop/gitlab/bulk_insert.rb
@@ -3,13 +3,13 @@
module RuboCop
module Cop
module Gitlab
# Cop that disallows the use of `Gitlab::Database.bulk_insert`, in favour of using
# the `BulkInsertSafe` module.
class BulkInsert < RuboCop::Cop::Cop
- MSG = 'Use the `BulkInsertSafe` concern, instead of using `Gitlab::Database.bulk_insert`. See https://docs.gitlab.com/ee/development/insert_into_tables_in_batches.html'
+ MSG = 'Use the `BulkInsertSafe` concern, instead of using `Gitlab::Database.main.bulk_insert`. See https://docs.gitlab.com/ee/development/insert_into_tables_in_batches.html'
def_node_matcher :raw_union?, <<~PATTERN
- (send (const (const _ :Gitlab) :Database) :bulk_insert ...)
+ (send (send (const (const _ :Gitlab) :Database) :main) :bulk_insert ...)
PATTERN
def on_send(node)
@@ -3,13 +3,13 @@
module Cop
module Gitlab
- # Cop that disallows the use of `Gitlab::Database.bulk_insert`, in favour of using
+ # Cop that disallows the use of `Gitlab::Database.main.bulk_insert`, in favour of using
# the `BulkInsertSafe` module.
class BulkInsert < RuboCop::Cop::Cop